# recreat - Indicators on Landscape Recreational Potential

recreat is a is a Python library for assessing landscape recreational potential in terms of 
dimensions of green-blue infrastructure provisioning, supply, and demand, through the analytical lens of recreation. 

